==> crm-commom-vo-1.1.9.8.release.jar: com/biz/crm/nebular/mdm/dict/resp/DictDataVo.java <==
package com.biz.crm.nebular.mdm.dict.resp;

import io.swagger.annotations.ApiModelProperty;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据字典值VO
 */
public class DictDataVo {

    /***字典编码*/
    @ApiModelProperty(value = "字典编码")
    private String dictCode;
    /***字典值*/
    @ApiModelProperty(value = "字典值")
    private String dictValue;
    /***字典值描述*/
    @ApiModelProperty(value = "字典描述")
    private String dictDesc;
    /***字典类型编码*/
    @ApiModelProperty(value = "字典类型编码")
    private String dictTypeCode;
    /***字典编码上级编码*/
    @ApiModelProperty(value = "上级字典编码（上级的dictCode）")
    private String parentDictCode;
    /***顺序*/
    @ApiModelProperty(value = "排序顺序")
    private String dictSort;
    /***扩展字段MAP*/
    @ApiModelProperty(value = "扩展字段map")
    private Map<String, String> extendMap = new HashMap<>(16);
    /***下级，树形结构接口才有值*/
    @ApiModelProperty(value = "下级")
    private List<DictDataVo> children;

    public String getDictCode() {
        return dictCode;
    }

    public void setDictCode(String dictCode) {
        this.dictCode = dictCode;
    }

    public String getDictValue() {
        return dictValue;
    }

    public void setDictValue(String dictValue) {
        this.dictValue = dictValue;
    }

    public String getDictDesc() {
        return dictDesc;
    }

    public void setDictDesc(String dictDesc) {
        this.dictDesc = dictDesc;
    }

    public String getDictTypeCode() {
        return dictTypeCode;
    }

    public void setDictTypeCode(String dictTypeCode) {
        this.dictTypeCode = dictTypeCode;
    }

    public String getParentDictCode() {
        return parentDictCode;
    }

    public void setParentDictCode(String parentDictCode) {
        this.parentDictCode = parentDictCode;
    }

    public String getDictSort() {
        return dictSort;
    }

    public void setDictSort(String dictSort) {
        this.dictSort = dictSort;
    }

    public Map<String, String> getExtendMap() {
        return extendMap;
    }

    public void setExtendMap(Map<String, String> extendMap) {
        this.extendMap = extendMap;
    }

    public List<DictDataVo> getChildren() {
        return children;
    }

    public void setChildren(List<DictDataVo> children) {
        this.children = children;
    }
}

==> crm-commom-vo-1.1.9.20.release.jar: com/biz/crm/nebular/mdm/dict/resp/DictDataVo.java <==
package com.biz.crm.nebular.mdm.dict.resp;

import io.swagger.annotations.ApiModelProperty;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据字典值VO
 */
public class DictDataVo {

    @ApiModelProperty(value = "字典编码")
    private String dictCode;
    @ApiModelProperty(value = "字典值")
    private String dictValue;
    @ApiModelProperty(value = "字典描述")
    private String dictDesc;
    @ApiModelProperty(value = "字典类型编码")
    private String dictTypeCode;
    @ApiModelProperty(value = "上级字典编码（上级的dictCode）")
    private String parentDictCode;
    @ApiModelProperty(value = "路径")
    private String path;
    @ApiModelProperty(value = "排序顺序")
    private String dictSort;
    @ApiModelProperty(value = "扩展字段map")
    private Map<String, String> extendMap = new HashMap<>(16);
    @ApiModelProperty(value = "下级，树形结构接口才有值")
    private List<DictDataVo> children;

    public String getDictCode() {
        return dictCode;
    }

    public void setDictCode(String dictCode) {
        this.dictCode = dictCode;
    }

    public String getDictValue() {
        return dictValue;
    }

    public void setDictValue(String dictValue) {
        this.dictValue = dictValue;
    }

    public String getDictDesc() {
        return dictDesc;
    }

    public void setDictDesc(String dictDesc) {
        this.dictDesc = dictDesc;
    }

    public String getDictTypeCode() {
        return dictTypeCode;
    }

    public void setDictTypeCode(String dictTypeCode) {
        this.dictTypeCode = dictTypeCode;
    }

    public String getParentDictCode() {
        return parentDictCode;
    }

    public void setParentDictCode(String parentDictCode) {
        this.parentDictCode = parentDictCode;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getDictSort() {
        return dictSort;
    }

    public void setDictSort(String dictSort) {
        this.dictSort = dictSort;
    }

    public Map<String, String> getExtendMap() {
        return extendMap;
    }

    public void setExtendMap(Map<String, String> extendMap) {
        this.extendMap = extendMap;
    }

    public List<DictDataVo> getChildren() {
        return children;
    }

    public void setChildren(List<DictDataVo> children) {
        this.children = children;
    }
}
